==> brmo-stufbg204-1.5.1-sources.jar: nl/egem/stuf/sector/bg/_0204/HHDAntwoord.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * huishouden binnen antwoordberichten
 * 
 * <p>Java class for HHD-antwoord complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HHD-antwoord">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHD-fund">
 *       &lt;sequence>
 *         &lt;element name="HHD" type="{http://www.egem.nl/StUF/sector/bg/0204}HHD-fund" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="HHDPRS" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHDPRS-rel">
 *                 &lt;sequence>
 *                   &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kennisgeving"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="HDDWOZ" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="WOZ" type="{http://www.egem.nl/StUF/sector/bg/0204}WOZ-kennisgeving"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HHD-antwoord", propOrder = {
    "hhd",
    "hhdprs",
    "hddwoz"
})
public class HHDAntwoord
    extends HHDFund
{

    @XmlElement(name = "HHD")
    protected List<HHDFund> hhd;
    @XmlElement(name = "HHDPRS", nillable = true)
    protected List<HHDAntwoord.HHDPRS> hhdprs;
    @XmlElement(name = "HDDWOZ", nillable = true)
    protected List<HHDAntwoord.HDDWOZ> hddwoz;

    /**
     * Gets the value of the hhd property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the hhd property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getHHD().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link HHDFund }
     * 
     * 
     */
    public List<HHDFund> getHHD() {
        if (hhd == null) {
            hhd = new ArrayList<HHDFund>();
        }
        return this.hhd;
    }

    /**
     * Gets the value of the hhdprs property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the hhdprs property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getHHDPRS().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link HHDAntwoord.HHDPRS }
     * 
     * 
     */
    public List<HHDAntwoord.HHDPRS> getHHDPRS() {
        if (hhdprs == null) {
            hhdprs = new ArrayList<HHDAntwoord.HHDPRS>();
        }
        return this.hhdprs;
    }

    /**
     * Gets the value of the hddwoz property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the hddwoz property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getHDDWOZ().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link HHDAntwoord.HDDWOZ }
     * 
     * 
     */
    public List<HHDAntwoord.HDDWOZ> getHDDWOZ() {
        if (hddwoz == null) {
            hddwoz = new ArrayList<HHDAntwoord.HDDWOZ>();
        }
        return this.hddwoz;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="WOZ" type="{http://www.egem.nl/StUF/sector/bg/0204}WOZ-kennisgeving"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "woz"
    })
    public static class HDDWOZ
        extends Relatie
    {

        @XmlElement(name = "WOZ", required = true, nillable = true)
        protected WOZKennisgeving woz;

        /**
         * Gets the value of the woz property.
         * 
         * @return
         *     possible object is
         *     {@link WOZKennisgeving }
         *     
         */
        public WOZKennisgeving getWOZ() {
            return woz;
        }

        /**
         * Sets the value of the woz property.
         * 
         * @param value
         *     allowed object is
         *     {@link WOZKennisgeving }
         *     
         */
        public void setWOZ(WOZKennisgeving value) {
            this.woz = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHDPRS-rel">
     *       &lt;sequence>
     *         &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kennisgeving"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "prs"
    })
    public static class HHDPRS
        extends HHDPRSRel
    {

        @XmlElement(name = "PRS", required = true, nillable = true)
        protected PRSKennisgeving prs;

        /**
         * Gets the value of the prs property.
         * 
         * @return
         *     possible object is
         *     {@link PRSKennisgeving }
         *     
         */
        public PRSKennisgeving getPRS() {
            return prs;
        }

        /**
         * Sets the value of the prs property.
         * 
         * @param value
         *     allowed object is
         *     {@link PRSKennisgeving }
         *     
         */
        public void setPRS(PRSKennisgeving value) {
            this.prs = value;
        }

    }

}

==> brmo-stufbg204-2.0.0-sources.jar: nl/egem/stuf/sector/bg/_0204/HHDAntwoord.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * huishouden binnen antwoordberichten
 * 
 * <p>Java class for HHD-antwoord complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HHD-antwoord"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHD-fund"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="HHD" type="{http://www.egem.nl/StUF/sector/bg/0204}HHD-fund" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;element name="HHDPRS" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHDPRS-rel"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kennisgeving"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="HDDWOZ" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="WOZ" type="{http://www.egem.nl/StUF/sector/bg/0204}WOZ-kennisgeving"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HHD-antwoord", propOrder = {
    "hhd",
    "hhdprs",
    "hddwoz"
})
public class HHDAntwoord
    extends HHDFund
{

    @XmlElement(name = "HHD")
    protected List<HHDFund> hhd;
    @XmlElement(name = "HHDPRS", nillable = true)
    protected List<HHDAntwoord.HHDPRS> hhdprs;
    @XmlElement(name = "HDDWOZ", nillable = true)
    protected List<HHDAntwoord.HDDWOZ> hddwoz;

    /**
     * Gets the value of the hhd property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the hhd property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getHHD().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link HHDFund }
     * 
     * 
     */
    public List<HHDFund> getHHD() {
        if (hhd == null) {
            hhd = new ArrayList<HHDFund>();
        }
        return this.hhd;
    }

    /**
     * Gets the value of the hhdprs property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the hhdprs property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getHHDPRS().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link HHDAntwoord.HHDPRS }
     * 
     * 
     */
    public List<HHDAntwoord.HHDPRS> getHHDPRS() {
        if (hhdprs == null) {
            hhdprs = new ArrayList<HHDAntwoord.HHDPRS>();
        }
        return this.hhdprs;
    }

    /**
     * Gets the value of the hddwoz property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the hddwoz property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getHDDWOZ().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link HHDAntwoord.HDDWOZ }
     * 
     * 
     */
    public List<HHDAntwoord.HDDWOZ> getHDDWOZ() {
        if (hddwoz == null) {
            hddwoz = new ArrayList<HHDAntwoord.HDDWOZ>();
        }
        return this.hddwoz;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="WOZ" type="{http://www.egem.nl/StUF/sector/bg/0204}WOZ-kennisgeving"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "woz"
    })
    public static class HDDWOZ
        extends Relatie
    {

        @XmlElement(name = "WOZ", required = true, nillable = true)
        protected WOZKennisgeving woz;

        /**
         * Gets the value of the woz property.
         * 
         * @return
         *     possible object is
         *     {@link WOZKennisgeving }
         *     
         */
        public WOZKennisgeving getWOZ() {
            return woz;
        }

        /**
         * Sets the value of the woz property.
         * 
         * @param value
         *     allowed object is
         *     {@link WOZKennisgeving }
         *     
         */
        public void setWOZ(WOZKennisgeving value) {
            this.woz = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHDPRS-rel"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kennisgeving"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "prs"
    })
    public static class HHDPRS
        extends HHDPRSRel
    {

        @XmlElement(name = "PRS", required = true, nillable = true)
        protected PRSKennisgeving prs;

        /**
         * Gets the value of the prs property.
         * 
         * @return
         *     possible object is
         *     {@link PRSKennisgeving }
         *     
         */
        public PRSKennisgeving getPRS() {
            return prs;
        }

        /**
         * Sets the value of the prs property.
         * 
         * @param value
         *     allowed object is
         *     {@link PRSKennisgeving }
         *     
         */
        public void setPRS(PRSKennisgeving value) {
            this.prs = value;
        }

    }

}
